@@ -1,18 +1,24 @@
 
 ## Allows us to define functions for each endpoint using closures
+#' @importFrom httr GET
+#' @importFrom dplyr bind_rows
 endpoint <- function(endpt, tidy_table = default_tidy){
   
   function(species_list, fields = NULL, limit = 200, server = getOption("FISHBASE_API", FISHBASE_API), ...){
     codes <- speccodes(species_list)
     dplyr::bind_rows(lapply(codes, function(code){
-      
-      if(!is.null(fields)) 
-        fields <- c("SpecCode", fields)
       args <- list(SpecCode = code,
-                   limit = limit, 
-                   fields = paste(fields, collapse=","))
+                   limit = limit)
+      if(!is.null(fields)) 
+        args <- c(args, 
+                  fields = paste(c("SpecCode", fields), 
+                                 collapse=","))
+       
       
-      resp <- httr::GET(paste0(server, "/", endpt), query = args, ..., httr::user_agent(make_ua()))
+      resp <- httr::GET(paste0(server, "/", endpt), 
+                        query = args, 
+                        ..., 
+                        httr::user_agent(make_ua()))
       data <- check_and_parse(resp)
       
       tidy_table(data, server = server)
@@ -43,8 +49,6 @@ make_ua <- function() {
     "automated_test"
   } else {
   versions <- c(rfishbase = as.character(packageVersion("rfishbase")),
-#                curl = RCurl::curlVersion()$version,
-#                Rcurl = as.character(packageVersion("RCurl")),
                 httr = as.character(packageVersion("httr")))
   paste0(names(versions), "/", versions, collapse = " ")
   }
