@@ -8,7 +8,7 @@ test_that("We can load taxa from the package database", {
 
 test_that("We can refresh the taxa list and use it in future calls", {
   
-  #if(TRUE) skip("skip full join, too demanding on server")
+  if(TRUE) skip("skip full join, too demanding on server")
 
   needs_api()  
   df <- load_taxa(update = TRUE, cache = TRUE)
