@@ -7,7 +7,8 @@ test_that("population_dynamics methods can all be called successfully", {
   df <- popchar("Oreochromis niloticus")
   expect_is(df, "data.frame")
   
-  df <- popgrowth("Oreochromis niloticus")
+  df <- popgrowth("Oreochromis niloticus", fields=
+                    "TLinfinity")
   expect_is(df, "data.frame")
   
   df <- length_length("Oreochromis niloticus")
